<?php
# On Tour (inc.ontour.php) -- Version 18-May-2006
# Copyright (c) 2003-2006 Jochen Kupperschmidt <webmaster@nwsnet.de>
# Released under the terms of the GNU General Public License
#  _                               _
# | |_ ___ _____ ___ _ _ _ ___ ___| |_
# |   | . |     | ._| | | | . |  _| . /
# |_|_|___|_|_|_|___|_____|___|_| |_|_\
#   http://homework.nwsnet.de/
#
# This script generates an index of available galleries by traversing direct
# subdirectories and looking for a lightweight YAML (http://www.yaml.org/) data
# file. If found, its information will be extracted and added to the index.
# HTML galleries with thumbnails of a bunch of images can be created with
# various imaging tools, e.g. IrfanView (http://www.irfanview.com/).
#
# Requirements:
#   - PHP 4/5
#   - Spyc (http://spyc.sourceforge.net/)
#     - Include the Spyc script fitting your PHP version (4/5) and rename it
#       to 'inc.spyc.php',
#
# Usage:
#     require_once('inc.ontour.php');
#     $items = readTourItems('.');


# Load Spyc YAML parser.
require_once('inc.spyc.php');

# Name of the data file in each subdirectory.
define('DATA_FILENAME', 'tour.yml');

function getDirectories($path, $reverse=True)
{
    # Traverse direct subdirectories.
    $dirs = array();
    $dir = dir($path);
    while (false !== ($entry = $dir->read())) {
        if (is_dir($entry) and ($entry != '.') and ($entry != '..')) {
            $dirs[] = $entry;
        }
    }
    $dir->close();

    # Sort directory names.
    if ($reverse) {
        rsort($dirs);
    } else {
        sort($dirs);
    }

    return $dirs;
}

function readTourItems($path)
{
    # Cycle through entries.
    $items = array();
    foreach (getDirectories($path, True) as $dir) {
        $file = $dir . '/' . DATA_FILENAME;
        if (file_exists($file)) {
            # Parse data file.
            $item = Spyc::YAMLLoad($file);
            if ($item) {
                # path
                $item['path'] = $dir . '/';

                # dates
                $format = '%m/%d/%Y';
                $item['start date'] = strftime($format, strtotime($item['start date']));
                $item['end date'] = strftime($format, strtotime($item['end date']));

                # videos
                if ($item['videos']) {
                    $videos = array();
                    foreach ($item['videos'] as $v) {
                        $videos[] = sprintf('<a href="%s%s">%s</a>', $item['path'], $v, $v);
                    }
                    $item['videos'] = join('<br />', $videos);
                }

                $items[] = $item;
            }
        }
    }
    return $items;
}
?>